//	ATtiny2313 Special Function Registers

enum SFR
{
	DIDR	= 0x21,
	UBRRH,
	UCSRC,

	ACSR	= 0x28,
	UBRRL,
	UCSRB,
	UCSRA,
	UDR,
	USICR,
	USISR,
	USIDR,
	PIND,
	DDRD,
	PORTD,
	GPIOR0,
	GPIOR1,
	GPIOR2,
	PINB,
	DDRB,
	PORTB,
	PINA,
	DDRA,
	PORTA,
	EECR,
	EEDR,
	EEAR,

	PCMSK	= 0x40,
	WDTCSR,
	TCCR1C,
	GTCCR,
	ICR1L,
	ICR1H,
	CLKPR,

	OCR1BL	= 0x48,
	OCR1BH,
	OCR1AL,
	OCR1AH,
	TCNT1L,
	TCNT1H,
	TCCR1B,
	TCCR1A,
	TCCR0A,
	OSCCAL,
	TCNT0,
	TCCR0B,
	MCUSR,
	MCUCR,
	OCR0A,
	SPMCSR,
	TIFR,
	TIMSK,
	EIFR,
	GIMSK,
	OCR0B,
	SPL,

	SREG	= 0x5f
};

/*
 *  The Register Bit names are represented by their bit number (0-7).
 */
//WinAVR-20080610iotn2313.hH
struct RB
{
	public const int

/* ATtiny Digital Input Disable Register DIDR */
	AIN1D	= 1,
	AIN0D	= 0,

/* ATtiny USART Control and Status Register C UCSRC */
	UMSEL	= 6,
	UPM1	= 5,
	UPM0	= 4,
	USBS	= 3,
	UCSZ1	= 2,
	UCSZ0	= 1,
	UCPOL	= 0,

/* ATtiny Analog Comparator Control and Status Register ACSR */
	ACD		= 7,
	ACBG	= 6,
	ACO		= 5,
	ACI		= 4,
	ACIE	= 3,
	ACIC	= 2,
	ACIS1	= 1,
	ACIS0	= 0,

/* ATtiny USART Control Register UCSRB */
	RXCIE	= 7,
	TXCIE	= 6,
	UDRIE	= 5,
	RXEN	= 4,
	TXEN	= 3,
	UCSZ2	= 2,
	RXB8	= 1,
	TXB8	= 0,

/* ATtiny USART Status Register UCSRA */
	RXC		= 7,
	TXC		= 6,
	UDRE	= 5,
	FE		= 4,
	DOR		= 3,
	UPE		= 2,
	U2X		= 1,
	MPCM	= 0,

/* ATtiny USI Control Register USICR */
	USISIE	= 7,
	USIOIE	= 6,
	USIWM1	= 5,
	USIWM0	= 4,
	USICS1	= 3,
	USICS0	= 2,
	USICLK	= 1,
	USITC	= 0,

/* ATtiny USI Status Register USISR */
	USISIF	= 7,
	USIOIF	= 6,
	USIPF	= 5,
	USIDC	= 4,
	USICNT3	= 3,
	USICNT2	= 2,
	USICNT1	= 1,
	USICNT0	= 0,

/* Input Pins, Port D PIND[6:0] */
	PIND6	= 6,
	PIND5	= 5,
	PIND4	= 4,
	PIND3	= 3,
	PIND2	= 2,
	PIND1	= 1,
	PIND0	= 0,

/* Data Direction Register, Port D DDRD[6:0] */
	DDD6	= 6,
	DDD5	= 5,
	DDD4	= 4,
	DDD3	= 3,
	DDD2	= 2,
	DDD1	= 1,
	DDD0	= 0,

/* Data Register, Port D PORTD[6:0] */
	PD6	= 6,
	PD5	= 5,
	PD4	= 4,
	PD3	= 3,
	PD2	= 2,
	PD1	= 1,
	PD0	= 0,

/* Input Pins, Port B PORTB[7:0] */
	PINB7	= 7,
	PINB6	= 6,
	PINB5	= 5,
	PINB4	= 4,
	PINB3	= 3,
	PINB2	= 2,
	PINB1	= 1,
	PINB0	= 0,

/* Data Direction Register, Port B PORTB[7:0] */
	DDB7	= 7,
	DDB6	= 6,
	DDB5	= 5,
	DDB4	= 4,
	DDB3	= 3,
	DDB2	= 2,
	DDB1	= 1,
	DDB0	= 0,

/* Data Register, Port B PORTB[7:0] */
	PB7	= 7,
	PB6	= 6,
	PB5	= 5,
	PB4	= 4,
	PB3	= 3,
	PB2	= 2,
	PB1	= 1,
	PB0	= 0,

/* Port A Input Pins Address PINA[2:0] */
	PINA2	= 2,
	PINA1	= 1,
	PINA0	= 0,

/* Port A Data Direction Register DDRA[2:0] */
	DDRA2	= 2,
	DDRA1	= 1,
	DDRA0	= 0,

/* Port A Data Register PORTA[2:0] */
	PA2	= 2,
	PA1	= 1,
	PA0	= 0,

/* ATtiny EEPROM Control Register EECR */
	EEPM1	= 5,
	EEPM0	= 4,
	EERIE	= 3,
	EEMPE	= 2,
	EEPE	= 1,
	EERE	= 0,

/* The EEPROM Address Register EEAR[6:0] */
	EEAR6	= 6,
	EEAR5	= 5,
	EEAR4	= 4,
	EEAR3	= 3,
	EEAR2	= 2,
	EEAR1	= 1,
	EEAR0	= 0,

/* ATtiny Pin Change Mask Register PCMSK PCINT[7:0] */
	PCINT7	= 7,
	PCINT6	= 6,
	PCINT5	= 5,
	PCINT4	= 4,
	PCINT3	= 3,
	PCINT2	= 2,
	PCINT1	= 1,
	PCINT0	= 0,

/* ATtiny Watchdog Timer Control Register WDTCSR */
	WDIF	= 7,
	WDIE	= 6,
	WDP3	= 5,
	WDCE	= 4,
	WDE		= 3,
	WDP2	= 2,
	WDP1	= 1,
	WDP0	= 0,

/* ATtiny Timer/Counter1 Control Register C TCCR1C */
	FOC1A	= 7,
	FOC1B	= 6,

/* General Timer/Counter Control Register GTCCR */
	PSR10	= 0,

/* ATtiny Clock Prescale Register */
	CLKPCE	= 7,
	CLKPS3	= 3,
	CLKPS2	= 2,
	CLKPS1	= 1,
	CLKPS0	= 0,

/* ATtiny Timer/Counter 1 Control and Status Register TCCR1B */
	ICNC1	= 7,
	ICES1	= 6,
	WGM13	= 4,
	WGM12	= 3,	/* Was CTC1 in AT90S2313 */
	CS12	= 2,
	CS11	= 1,
	CS10	= 0,

/* ATtiny Timer/Counter 1 Control Register TCCR1A */
	COM1A1	= 7,
	COM1A0	= 6,
	COM1B1	= 5,
	COM1B0	= 4,
	WGM11	= 1,	/* Was PWM11 in AT90S2313 */
	WGM10	= 0,	/* Was PWM10 in AT90S2313 */

/* ATtiny Timer/Counter Control Register A TCCR0A */
	COM0A1	= 7,
	COM0A0	= 6,
	COM0B1	= 5,
	COM0B0	= 4,
	WGM01	= 1,
	WGM00	= 0,

/* ATtiny Oscillator Calibration Register OSCCAL[6:0] */
	CAL6	= 6,
	CAL5	= 5,
	CAL4	= 4,
	CAL3	= 3,
	CAL2	= 2,
	CAL1	= 1,
	CAL0	= 0,

/* ATtiny Timer/Counter 0 Control Register TCCR0B */
	FOC0A	= 7,
	FOC0B	= 6,
	WGM02	= 3,
	CS02	= 2,
	CS01	= 1,
	CS00	= 0,

/* ATtiny MCU Status Register MCUSR */
	WDRF	= 3,
	BORF	= 2,
	EXTRF	= 1,
	PORF	= 0,

/* ATtiny MCU general Control Register MCUCR */
	PUD		= 7,
	SM1		= 6,
	SE		= 5,
	SM0		= 4,	/* Some preliminary ATtiny2313 data sheets incorrectly refer
						to this bit as SMD; was SM in AT90S2313. */
	ISC11	= 3,
	ISC10	= 2,
	ISC01	= 1,
	ISC00	= 0,

/* ATtiny Store Program Memory Control and Status Register SPMCSR */
	CTPB		= 4,
	RFLB		= 3,
	PGWRT		= 2,
	PGERS		= 1,
	SPMEN		= 0,	/* The name is used in ATtiny2313.xml file. */
	SELFPRGEN	= 0,	/* The name is used in datasheet. */
	SELFPRGE	= 0,	/* The name is left for compatibility. */

/* ATtiny Timer/Counter Interrupt Flag register TIFR */
	TOV1	= 7,
	OCF1A	= 6,
	OCF1B	= 5,
	ICF1	= 3,
	OCF0B	= 2,
	TOV0	= 1,
	OCF0A	= 0,

/* ATtiny Timer/Counter Interrupt MaSK register TIMSK */
	TOIE1	= 7,
	OCIE1A	= 6,
	OCIE1B	= 5,
	ICIE1	= 3,
	OCIE0B	= 2,
	TOIE0	= 1,
	OCIE0A	= 0,

/* ATtiny External Interrupt Flag Register EIFR, was GIFR */
	INTF1	= 7,
	INTF0	= 6,
	PCIF	= 5,

/* ATtiny General Interrupt MaSK register GIMSK */
	INT1	= 7,
	INT0	= 6,
	PCIE	= 5,
	
	//<,><;>~Xh~
	_RB_	= 0;
};
