﻿using System;

namespace LcdClockControler
{
	/*	LCD Clock typeP	コマンド定義
	 * 下位4bit：命令の長さ(byte)
	 * 8bit全体として：命令の種類
	 *（例）0x17 … 命令番号=17、命令の長さ=7byte
	 */
	struct CMD
	{
		public const int
			SET_DATE		= 0x17,		//日時を設定する
			SET_DISPLAY		= 0x21,		//表示モードを設定する
			SET_CON_BKLT	= 0x32,		//コントラスト、バックライトを設定する
			GET_VALUE		= 0x40,		//現在の設定値を取得する
			DRAWSTOP		= 0x51,		//描画停止／再開する（時計動作自体は継続）
			BUF_CLEAR		= 0x00;		//受信バッファをクリアする
	};
	
	/*
	 * LCD Clock typeP
	 */
	class LcdClock
	{
		private CdcIO cdcio;
		public int dispMode, contrast, backlight;
		
		//コンストラクタ
		public LcdClock()
		{
			cdcio = null;
			dispMode = contrast = backlight = 0;
		}
		
		//CdcIOオブジェクトをセットする
		public void setCdcIO(CdcIO cdcio)
		{
			this.cdcio = cdcio;
		}

		//日時を設定する
		public bool setDate(DateTime dt)
		{
			bool ret = cdcio.sendByte(CMD.SET_DATE)
					&& cdcio.sendByte(dt.Year % 100)	//年（西暦の下2桁）
					&& cdcio.sendByte(dt.Month)		//月
					&& cdcio.sendByte(dt.Day)		//日
					&& cdcio.sendByte((int)dt.DayOfWeek)	//曜日（0:日,1:月～6:土）
					&& cdcio.sendByte(dt.Hour)		//時(24時間制)
					&& cdcio.sendByte(dt.Minute)	//分
					&& cdcio.sendByte(dt.Second);	//秒
			return ret;
		}

		//表示モードを設定する
		public bool setDisplayMode(int mode)
		{
			//0:西暦／24時間制, 1:西暦／12時間制, 2:元号／24時間制, 3:元号／12時間制
			if (mode < 0 || 3 < mode) return false;

			bool ret = cdcio.sendByte(CMD.SET_DISPLAY)
					&& cdcio.sendByte(mode);
			
			if (ret) dispMode = mode;
			return ret;
		}

		//コントラスト、バックライトを設定する
		public bool setConBkLt(int con, int bklt)
		{
			bool ret = cdcio.sendByte(CMD.SET_CON_BKLT)
					&& cdcio.sendByte(con)		//コントラスト	0x00-0x80
					&& cdcio.sendByte(bklt);	//バックライト	0x00-0xFF
			
			if (ret)
			{
				contrast = con;
				backlight = bklt;
			}
			return ret;
		}

		//現在の設定値を取得する
		public bool getValue()
		{
			if (!cdcio.sendByte(CMD.GET_VALUE)) return false;
			
			int value = cdcio.receiveByte();
			if (cdcio.cmdGetError) return false;
			dispMode = value;

			value = cdcio.receiveByte();
			if (cdcio.cmdGetError) return false;
			contrast = value;

			value = cdcio.receiveByte();
			if (cdcio.cmdGetError) return false;
			backlight = value;
			
			return true;
		}
		
	}
	
}
